diff -b -u -r -N ../vim-5.0/src/Makefile src/Makefile
--- ../vim-5.0/src/Makefile	Thu Feb 19 06:53:04 1998
+++ src/Makefile	Fri Feb 20 22:16:54 1998
@@ -816,6 +816,7 @@
 	undo.c \
 	version.c \
 	window.c \
+	hangul.c \
 	$(OS_EXTRA_SRC)
 
 SRC =	$(BASIC_SRC) $(GUI_SRC) $(PERL_SRC) $(PYTHON_SRC)
@@ -858,6 +859,7 @@
 	ui.o \
 	undo.o \
 	window.o \
+	hangul.o \
 	$(GUI_OBJ) \
 	$(PERL_OBJ) \
 	$(PYTHON_OBJ) \
@@ -1393,3 +1395,4 @@
 if_sniff.o: if_sniff.c vim.h config.h feature.h os_unix.h osdef.h \
  ascii.h keymap.h term.h macros.h regexp.h structs.h gui.h globals.h \
  option.h ex_cmds.h proto.h os_unixx.h
+hangul.o: hangul.c hangul.h
diff -b -u -r -N ../vim-5.0/src/edit.c src/edit.c
--- ../vim-5.0/src/edit.c	Thu Feb 19 04:53:45 1998
+++ src/edit.c	Fri Feb 20 21:24:22 1998
@@ -11,6 +11,8 @@
  */
 
 #include "vim.h"
+#include "winime.h"
+#include "hangul.h"
 
 #ifdef INSERT_EXPAND
 /*
@@ -252,6 +254,9 @@
     }
     else
 	State = INSERT;
+#ifdef USE_GUI_WIN32
+        ImeSetOriginMode(); /* hangule */
+#endif
     /*
      * Need to recompute the cursor position, it might move when the cursor is
      * on a TAB or special character.
@@ -477,6 +482,20 @@
 	    c = Ctrl('V');	/* pretend CTRL-V is last typed character */
 	    continue;
 	}
+	/* hangul start */
+	if( IsLeadByte((char_u)c) ){
+	    char	c2;
+
+	    c2 = get_literal();
+	    insert_special( c, TRUE , FALSE);
+	    insert_special( c2, TRUE , FALSE);
+	    /*redrawing();*/
+
+	    need_redraw = TRUE;
+
+	    continue;
+	}
+    /* hangul end */
 
 #ifdef CINDENT
 	if (curbuf->b_p_cin
@@ -615,6 +634,9 @@
 		break;
 	    }
 doESCkey:
+#ifdef USE_GUI_WIN32
+	    ImeSetEnglishMode();
+#endif
 	    /*
 	     * This is the ONLY return from edit()!
 	     */
@@ -3170,11 +3192,16 @@
     int
 oneright()
 {
-    char_u *ptr;
+    /* hangul */
+    char_u *ptr, *to;
 
-    ptr = ml_get_cursor();
-    if (*ptr++ == NUL || *ptr == NUL)
-	return FAIL;
+    to = ptr = ml_get_cursor();
+    if (*ptr++ == NUL || *ptr == NUL) return FAIL;
+
+    if( (*to)&0x80 && h_is_correct( curwin->w_cursor.col, to )){
+        if( *(ptr+1)!=NUL )	++curwin->w_cursor.col;
+        else	return FAIL;
+    }
     curwin->w_set_curswant = TRUE;
     ++curwin->w_cursor.col;
     return OK;
@@ -3183,10 +3210,17 @@
     int
 oneleft()
 {
+    /* hangul*/
     if (curwin->w_cursor.col == 0)
 	return FAIL;
     curwin->w_set_curswant = TRUE;
     --curwin->w_cursor.col;
+#ifdef USE_GUI_WIN32
+    AdjustCursorForHangul(); /*hangul*/
+#else
+    if( !h_is_correct( curwin->w_cursor.col, ml_get_cursor() )) --curwin->w_cursor.col;
+#endif
+    
     return OK;
 }
 
diff -b -u -r -N ../vim-5.0/src/ex_getln.c src/ex_getln.c
--- ../vim-5.0/src/ex_getln.c	Mon Feb  9 05:52:36 1998
+++ src/ex_getln.c	Fri Feb 20 19:51:17 1998
@@ -11,6 +11,7 @@
  */
 
 #include "vim.h"
+#include "hangul.h"
 
 /*
  * Variables shared between getcmdline(), redrawcmdline() and others.
@@ -723,6 +724,12 @@
 	else
 	{
 	    IObuff[0] = c;
+	    /* begin hangul (command line ѱ ̵)*/ 
+        if ( IsLeadByte((char_u)c) ) {
+            IObuff[1] = vgetc();
+            put_on_cmdline(IObuff, 2, TRUE);
+        }
+        else  /* end hangul */
 	    put_on_cmdline(IObuff, 1, TRUE);
 	}
 	goto cmdline_changed;
diff -b -u -r -N ../vim-5.0/src/gui.c src/gui.c
--- ../vim-5.0/src/gui.c	Sun Feb 15 04:51:53 1998
+++ src/gui.c	Fri Feb 20 19:55:48 1998
@@ -1012,6 +1012,12 @@
     gui_mch_flush();		    /* In case vim decides to take a nap */
 }
 
+void DisplayCompString(char_u *s,int len)
+{
+    /*hangul*/
+    gui_outstr_nowrap(s,len,GUI_MON_TRS_CURSOR , (GuiColor)0, (GuiColor)0 ,0); 
+}
+
     static void
 gui_outstr(s, len)
     char_u  *s;
diff -b -u -r -N ../vim-5.0/src/gvim_vc5.mak src/gvim_vc5.mak
--- ../vim-5.0/src/gvim_vc5.mak	Thu Jan  1 09:00:00 1970
+++ src/gvim_vc5.mak	Fri Feb 20 21:57:25 1998
@@ -0,0 +1,8854 @@
+# Microsoft Developer Studio Generated NMAKE File, Based on Gvim_vc5.dsp
+!IF "$(CFG)" == ""
+CFG=Vim - Win32 Release
+!MESSAGE No configuration specified. Defaulting to Vim - Win32 Release.
+!ENDIF 
+
+!IF "$(CFG)" != "Vim - Win32 Release" && "$(CFG)" != "Vim - Win32 Debug" &&\
+ "$(CFG)" != "Vim - Win32 Release with Debug"
+!MESSAGE Invalid configuration "$(CFG)" specified.
+!MESSAGE You can specify a configuration when running NMAKE
+!MESSAGE by defining the macro CFG on the command line. For example:
+!MESSAGE 
+!MESSAGE NMAKE /f "Gvim_vc5.mak" CFG="Vim - Win32 Release"
+!MESSAGE 
+!MESSAGE Possible choices for configuration are:
+!MESSAGE 
+!MESSAGE "Vim - Win32 Release" (based on "Win32 (x86) Console Application")
+!MESSAGE "Vim - Win32 Debug" (based on "Win32 (x86) Console Application")
+!MESSAGE "Vim - Win32 Release with Debug" (based on\
+ "Win32 (x86) Console Application")
+!MESSAGE 
+!ERROR An invalid configuration is specified.
+!ENDIF 
+
+!IF "$(OS)" == "Windows_NT"
+NULL=
+!ELSE 
+NULL=nul
+!ENDIF 
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+OUTDIR=.\Rel
+INTDIR=.\Rel
+
+!IF "$(RECURSE)" == "0" 
+
+ALL : ".\gvim.exe"
+
+!ELSE 
+
+ALL : ".\gvim.exe"
+
+!ENDIF 
+
+CLEAN :
+	-@erase "$(INTDIR)\buffer.obj"
+	-@erase "$(INTDIR)\charset.obj"
+	-@erase "$(INTDIR)\digraph.obj"
+	-@erase "$(INTDIR)\edit.obj"
+	-@erase "$(INTDIR)\eval.obj"
+	-@erase "$(INTDIR)\ex_cmds.obj"
+	-@erase "$(INTDIR)\ex_docmd.obj"
+	-@erase "$(INTDIR)\ex_getln.obj"
+	-@erase "$(INTDIR)\fileio.obj"
+	-@erase "$(INTDIR)\getchar.obj"
+	-@erase "$(INTDIR)\gui.obj"
+	-@erase "$(INTDIR)\gui_w32.obj"
+	-@erase "$(INTDIR)\hangul.obj"
+	-@erase "$(INTDIR)\main.obj"
+	-@erase "$(INTDIR)\mark.obj"
+	-@erase "$(INTDIR)\memfile.obj"
+	-@erase "$(INTDIR)\memline.obj"
+	-@erase "$(INTDIR)\message.obj"
+	-@erase "$(INTDIR)\misc1.obj"
+	-@erase "$(INTDIR)\misc2.obj"
+	-@erase "$(INTDIR)\normal.obj"
+	-@erase "$(INTDIR)\ops.obj"
+	-@erase "$(INTDIR)\option.obj"
+	-@erase "$(INTDIR)\os_w32exe.obj"
+	-@erase "$(INTDIR)\os_win32.obj"
+	-@erase "$(INTDIR)\quickfix.obj"
+	-@erase "$(INTDIR)\regexp.obj"
+	-@erase "$(INTDIR)\screen.obj"
+	-@erase "$(INTDIR)\search.obj"
+	-@erase "$(INTDIR)\syntax.obj"
+	-@erase "$(INTDIR)\tag.obj"
+	-@erase "$(INTDIR)\term.obj"
+	-@erase "$(INTDIR)\ui.obj"
+	-@erase "$(INTDIR)\undo.obj"
+	-@erase "$(INTDIR)\vc50.idb"
+	-@erase "$(INTDIR)\version.obj"
+	-@erase "$(INTDIR)\vim.res"
+	-@erase "$(INTDIR)\window.obj"
+	-@erase "$(INTDIR)\winime.obj"
+	-@erase ".\gvim.exe"
+
+"$(OUTDIR)" :
+    if not exist "$(OUTDIR)/$(NULL)" mkdir "$(OUTDIR)"
+
+CPP=cl.exe
+CPP_PROJ=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+CPP_OBJS=.\Rel/
+CPP_SBRS=.
+
+.c{$(CPP_OBJS)}.obj::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.cpp{$(CPP_OBJS)}.obj::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.cxx{$(CPP_OBJS)}.obj::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.c{$(CPP_SBRS)}.sbr::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.cpp{$(CPP_SBRS)}.sbr::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.cxx{$(CPP_SBRS)}.sbr::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+RSC=rc.exe
+RSC_PROJ=/l 0x409 /fo"$(INTDIR)\vim.res" /d "NDEBUG" 
+BSC32=bscmake.exe
+BSC32_FLAGS=/nologo /o"$(OUTDIR)\Gvim_vc5.bsc" 
+BSC32_SBRS= \
+	
+LINK32=link.exe
+LINK32_FLAGS=libc.lib oldnames.lib kernel32.lib user32.lib gdi32.lib\
+ winspool.lib comdlg32.lib advapi32.lib shell32.lib imm32.lib /nologo\
+ /subsystem:windows /incremental:no /pdb:"$(OUTDIR)\gvim.pdb" /machine:I386\
+ /nodefaultlib /out:".\gvim.exe" 
+LINK32_OBJS= \
+	"$(INTDIR)\buffer.obj" \
+	"$(INTDIR)\charset.obj" \
+	"$(INTDIR)\digraph.obj" \
+	"$(INTDIR)\edit.obj" \
+	"$(INTDIR)\eval.obj" \
+	"$(INTDIR)\ex_cmds.obj" \
+	"$(INTDIR)\ex_docmd.obj" \
+	"$(INTDIR)\ex_getln.obj" \
+	"$(INTDIR)\fileio.obj" \
+	"$(INTDIR)\getchar.obj" \
+	"$(INTDIR)\gui.obj" \
+	"$(INTDIR)\gui_w32.obj" \
+	"$(INTDIR)\hangul.obj" \
+	"$(INTDIR)\main.obj" \
+	"$(INTDIR)\mark.obj" \
+	"$(INTDIR)\memfile.obj" \
+	"$(INTDIR)\memline.obj" \
+	"$(INTDIR)\message.obj" \
+	"$(INTDIR)\misc1.obj" \
+	"$(INTDIR)\misc2.obj" \
+	"$(INTDIR)\normal.obj" \
+	"$(INTDIR)\ops.obj" \
+	"$(INTDIR)\option.obj" \
+	"$(INTDIR)\os_w32exe.obj" \
+	"$(INTDIR)\os_win32.obj" \
+	"$(INTDIR)\quickfix.obj" \
+	"$(INTDIR)\regexp.obj" \
+	"$(INTDIR)\screen.obj" \
+	"$(INTDIR)\search.obj" \
+	"$(INTDIR)\syntax.obj" \
+	"$(INTDIR)\tag.obj" \
+	"$(INTDIR)\term.obj" \
+	"$(INTDIR)\ui.obj" \
+	"$(INTDIR)\undo.obj" \
+	"$(INTDIR)\version.obj" \
+	"$(INTDIR)\vim.res" \
+	"$(INTDIR)\window.obj" \
+	"$(INTDIR)\winime.obj"
+
+".\gvim.exe" : "$(OUTDIR)" $(DEF_FILE) $(LINK32_OBJS)
+    $(LINK32) @<<
+  $(LINK32_FLAGS) $(LINK32_OBJS)
+<<
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+OUTDIR=.\Dbg
+INTDIR=.\Dbg
+# Begin Custom Macros
+OutDir=.\.\Dbg
+# End Custom Macros
+
+!IF "$(RECURSE)" == "0" 
+
+ALL : ".\gvimd.exe" "$(OUTDIR)\Gvim_vc5.bsc"
+
+!ELSE 
+
+ALL : ".\gvimd.exe" "$(OUTDIR)\Gvim_vc5.bsc"
+
+!ENDIF 
+
+CLEAN :
+	-@erase "$(INTDIR)\buffer.obj"
+	-@erase "$(INTDIR)\buffer.sbr"
+	-@erase "$(INTDIR)\charset.obj"
+	-@erase "$(INTDIR)\charset.sbr"
+	-@erase "$(INTDIR)\digraph.obj"
+	-@erase "$(INTDIR)\digraph.sbr"
+	-@erase "$(INTDIR)\edit.obj"
+	-@erase "$(INTDIR)\edit.sbr"
+	-@erase "$(INTDIR)\eval.obj"
+	-@erase "$(INTDIR)\eval.sbr"
+	-@erase "$(INTDIR)\ex_cmds.obj"
+	-@erase "$(INTDIR)\ex_cmds.sbr"
+	-@erase "$(INTDIR)\ex_docmd.obj"
+	-@erase "$(INTDIR)\ex_docmd.sbr"
+	-@erase "$(INTDIR)\ex_getln.obj"
+	-@erase "$(INTDIR)\ex_getln.sbr"
+	-@erase "$(INTDIR)\fileio.obj"
+	-@erase "$(INTDIR)\fileio.sbr"
+	-@erase "$(INTDIR)\getchar.obj"
+	-@erase "$(INTDIR)\getchar.sbr"
+	-@erase "$(INTDIR)\gui.obj"
+	-@erase "$(INTDIR)\gui.sbr"
+	-@erase "$(INTDIR)\gui_w32.obj"
+	-@erase "$(INTDIR)\gui_w32.sbr"
+	-@erase "$(INTDIR)\hangul.obj"
+	-@erase "$(INTDIR)\hangul.sbr"
+	-@erase "$(INTDIR)\main.obj"
+	-@erase "$(INTDIR)\main.sbr"
+	-@erase "$(INTDIR)\mark.obj"
+	-@erase "$(INTDIR)\mark.sbr"
+	-@erase "$(INTDIR)\memfile.obj"
+	-@erase "$(INTDIR)\memfile.sbr"
+	-@erase "$(INTDIR)\memline.obj"
+	-@erase "$(INTDIR)\memline.sbr"
+	-@erase "$(INTDIR)\message.obj"
+	-@erase "$(INTDIR)\message.sbr"
+	-@erase "$(INTDIR)\misc1.obj"
+	-@erase "$(INTDIR)\misc1.sbr"
+	-@erase "$(INTDIR)\misc2.obj"
+	-@erase "$(INTDIR)\misc2.sbr"
+	-@erase "$(INTDIR)\normal.obj"
+	-@erase "$(INTDIR)\normal.sbr"
+	-@erase "$(INTDIR)\ops.obj"
+	-@erase "$(INTDIR)\ops.sbr"
+	-@erase "$(INTDIR)\option.obj"
+	-@erase "$(INTDIR)\option.sbr"
+	-@erase "$(INTDIR)\os_w32exe.obj"
+	-@erase "$(INTDIR)\os_w32exe.sbr"
+	-@erase "$(INTDIR)\os_win32.obj"
+	-@erase "$(INTDIR)\os_win32.sbr"
+	-@erase "$(INTDIR)\quickfix.obj"
+	-@erase "$(INTDIR)\quickfix.sbr"
+	-@erase "$(INTDIR)\regexp.obj"
+	-@erase "$(INTDIR)\regexp.sbr"
+	-@erase "$(INTDIR)\screen.obj"
+	-@erase "$(INTDIR)\screen.sbr"
+	-@erase "$(INTDIR)\search.obj"
+	-@erase "$(INTDIR)\search.sbr"
+	-@erase "$(INTDIR)\syntax.obj"
+	-@erase "$(INTDIR)\syntax.sbr"
+	-@erase "$(INTDIR)\tag.obj"
+	-@erase "$(INTDIR)\tag.sbr"
+	-@erase "$(INTDIR)\term.obj"
+	-@erase "$(INTDIR)\term.sbr"
+	-@erase "$(INTDIR)\ui.obj"
+	-@erase "$(INTDIR)\ui.sbr"
+	-@erase "$(INTDIR)\undo.obj"
+	-@erase "$(INTDIR)\undo.sbr"
+	-@erase "$(INTDIR)\vc50.idb"
+	-@erase "$(INTDIR)\vc50.pdb"
+	-@erase "$(INTDIR)\version.obj"
+	-@erase "$(INTDIR)\version.sbr"
+	-@erase "$(INTDIR)\vim.res"
+	-@erase "$(INTDIR)\window.obj"
+	-@erase "$(INTDIR)\window.sbr"
+	-@erase "$(INTDIR)\winime.obj"
+	-@erase "$(INTDIR)\winime.sbr"
+	-@erase "$(OUTDIR)\Gvim_vc5.bsc"
+	-@erase ".\gvimd.exe"
+
+"$(OUTDIR)" :
+    if not exist "$(OUTDIR)/$(NULL)" mkdir "$(OUTDIR)"
+
+CPP=cl.exe
+CPP_PROJ=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+CPP_OBJS=.\Dbg/
+CPP_SBRS=.\Dbg/
+
+.c{$(CPP_OBJS)}.obj::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.cpp{$(CPP_OBJS)}.obj::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.cxx{$(CPP_OBJS)}.obj::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.c{$(CPP_SBRS)}.sbr::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.cpp{$(CPP_SBRS)}.sbr::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.cxx{$(CPP_SBRS)}.sbr::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+RSC=rc.exe
+RSC_PROJ=/l 0x409 /fo"$(INTDIR)\vim.res" /d "_DEBUG" 
+BSC32=bscmake.exe
+BSC32_FLAGS=/nologo /o"$(OUTDIR)\Gvim_vc5.bsc" 
+BSC32_SBRS= \
+	"$(INTDIR)\buffer.sbr" \
+	"$(INTDIR)\charset.sbr" \
+	"$(INTDIR)\digraph.sbr" \
+	"$(INTDIR)\edit.sbr" \
+	"$(INTDIR)\eval.sbr" \
+	"$(INTDIR)\ex_cmds.sbr" \
+	"$(INTDIR)\ex_docmd.sbr" \
+	"$(INTDIR)\ex_getln.sbr" \
+	"$(INTDIR)\fileio.sbr" \
+	"$(INTDIR)\getchar.sbr" \
+	"$(INTDIR)\gui.sbr" \
+	"$(INTDIR)\gui_w32.sbr" \
+	"$(INTDIR)\hangul.sbr" \
+	"$(INTDIR)\main.sbr" \
+	"$(INTDIR)\mark.sbr" \
+	"$(INTDIR)\memfile.sbr" \
+	"$(INTDIR)\memline.sbr" \
+	"$(INTDIR)\message.sbr" \
+	"$(INTDIR)\misc1.sbr" \
+	"$(INTDIR)\misc2.sbr" \
+	"$(INTDIR)\normal.sbr" \
+	"$(INTDIR)\ops.sbr" \
+	"$(INTDIR)\option.sbr" \
+	"$(INTDIR)\os_w32exe.sbr" \
+	"$(INTDIR)\os_win32.sbr" \
+	"$(INTDIR)\quickfix.sbr" \
+	"$(INTDIR)\regexp.sbr" \
+	"$(INTDIR)\screen.sbr" \
+	"$(INTDIR)\search.sbr" \
+	"$(INTDIR)\syntax.sbr" \
+	"$(INTDIR)\tag.sbr" \
+	"$(INTDIR)\term.sbr" \
+	"$(INTDIR)\ui.sbr" \
+	"$(INTDIR)\undo.sbr" \
+	"$(INTDIR)\version.sbr" \
+	"$(INTDIR)\window.sbr" \
+	"$(INTDIR)\winime.sbr"
+
+"$(OUTDIR)\Gvim_vc5.bsc" : "$(OUTDIR)" $(BSC32_SBRS)
+    $(BSC32) @<<
+  $(BSC32_FLAGS) $(BSC32_SBRS)
+<<
+
+LINK32=link.exe
+LINK32_FLAGS=libcd.lib oldnames.lib kernel32.lib user32.lib gdi32.lib\
+ winspool.lib comdlg32.lib advapi32.lib shell32.lib imm32.lib /nologo\
+ /subsystem:windows /profile /debug /machine:I386 /nodefaultlib\
+ /out:".\gvimd.exe" 
+LINK32_OBJS= \
+	"$(INTDIR)\buffer.obj" \
+	"$(INTDIR)\charset.obj" \
+	"$(INTDIR)\digraph.obj" \
+	"$(INTDIR)\edit.obj" \
+	"$(INTDIR)\eval.obj" \
+	"$(INTDIR)\ex_cmds.obj" \
+	"$(INTDIR)\ex_docmd.obj" \
+	"$(INTDIR)\ex_getln.obj" \
+	"$(INTDIR)\fileio.obj" \
+	"$(INTDIR)\getchar.obj" \
+	"$(INTDIR)\gui.obj" \
+	"$(INTDIR)\gui_w32.obj" \
+	"$(INTDIR)\hangul.obj" \
+	"$(INTDIR)\main.obj" \
+	"$(INTDIR)\mark.obj" \
+	"$(INTDIR)\memfile.obj" \
+	"$(INTDIR)\memline.obj" \
+	"$(INTDIR)\message.obj" \
+	"$(INTDIR)\misc1.obj" \
+	"$(INTDIR)\misc2.obj" \
+	"$(INTDIR)\normal.obj" \
+	"$(INTDIR)\ops.obj" \
+	"$(INTDIR)\option.obj" \
+	"$(INTDIR)\os_w32exe.obj" \
+	"$(INTDIR)\os_win32.obj" \
+	"$(INTDIR)\quickfix.obj" \
+	"$(INTDIR)\regexp.obj" \
+	"$(INTDIR)\screen.obj" \
+	"$(INTDIR)\search.obj" \
+	"$(INTDIR)\syntax.obj" \
+	"$(INTDIR)\tag.obj" \
+	"$(INTDIR)\term.obj" \
+	"$(INTDIR)\ui.obj" \
+	"$(INTDIR)\undo.obj" \
+	"$(INTDIR)\version.obj" \
+	"$(INTDIR)\vim.res" \
+	"$(INTDIR)\window.obj" \
+	"$(INTDIR)\winime.obj"
+
+".\gvimd.exe" : "$(OUTDIR)" $(DEF_FILE) $(LINK32_OBJS)
+    $(LINK32) @<<
+  $(LINK32_FLAGS) $(LINK32_OBJS)
+<<
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+OUTDIR=.\RelDebug
+INTDIR=.\RelDebug
+
+!IF "$(RECURSE)" == "0" 
+
+ALL : ".\gvimrwd.exe"
+
+!ELSE 
+
+ALL : ".\gvimrwd.exe"
+
+!ENDIF 
+
+CLEAN :
+	-@erase "$(INTDIR)\buffer.obj"
+	-@erase "$(INTDIR)\charset.obj"
+	-@erase "$(INTDIR)\digraph.obj"
+	-@erase "$(INTDIR)\edit.obj"
+	-@erase "$(INTDIR)\eval.obj"
+	-@erase "$(INTDIR)\ex_cmds.obj"
+	-@erase "$(INTDIR)\ex_docmd.obj"
+	-@erase "$(INTDIR)\ex_getln.obj"
+	-@erase "$(INTDIR)\fileio.obj"
+	-@erase "$(INTDIR)\getchar.obj"
+	-@erase "$(INTDIR)\gui.obj"
+	-@erase "$(INTDIR)\gui_w32.obj"
+	-@erase "$(INTDIR)\hangul.obj"
+	-@erase "$(INTDIR)\main.obj"
+	-@erase "$(INTDIR)\mark.obj"
+	-@erase "$(INTDIR)\memfile.obj"
+	-@erase "$(INTDIR)\memline.obj"
+	-@erase "$(INTDIR)\message.obj"
+	-@erase "$(INTDIR)\misc1.obj"
+	-@erase "$(INTDIR)\misc2.obj"
+	-@erase "$(INTDIR)\normal.obj"
+	-@erase "$(INTDIR)\ops.obj"
+	-@erase "$(INTDIR)\option.obj"
+	-@erase "$(INTDIR)\os_w32exe.obj"
+	-@erase "$(INTDIR)\os_win32.obj"
+	-@erase "$(INTDIR)\quickfix.obj"
+	-@erase "$(INTDIR)\regexp.obj"
+	-@erase "$(INTDIR)\screen.obj"
+	-@erase "$(INTDIR)\search.obj"
+	-@erase "$(INTDIR)\syntax.obj"
+	-@erase "$(INTDIR)\tag.obj"
+	-@erase "$(INTDIR)\term.obj"
+	-@erase "$(INTDIR)\ui.obj"
+	-@erase "$(INTDIR)\undo.obj"
+	-@erase "$(INTDIR)\vc50.idb"
+	-@erase "$(INTDIR)\vc50.pdb"
+	-@erase "$(INTDIR)\version.obj"
+	-@erase "$(INTDIR)\vim.res"
+	-@erase "$(INTDIR)\window.obj"
+	-@erase "$(INTDIR)\winime.obj"
+	-@erase ".\gvimrwd.exe"
+
+"$(OUTDIR)" :
+    if not exist "$(OUTDIR)/$(NULL)" mkdir "$(OUTDIR)"
+
+CPP=cl.exe
+CPP_PROJ=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+CPP_OBJS=.\RelDebug/
+CPP_SBRS=.
+
+.c{$(CPP_OBJS)}.obj::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.cpp{$(CPP_OBJS)}.obj::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.cxx{$(CPP_OBJS)}.obj::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.c{$(CPP_SBRS)}.sbr::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.cpp{$(CPP_SBRS)}.sbr::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+.cxx{$(CPP_SBRS)}.sbr::
+   $(CPP) @<<
+   $(CPP_PROJ) $< 
+<<
+
+RSC=rc.exe
+RSC_PROJ=/l 0x409 /fo"$(INTDIR)\vim.res" /d "NDEBUG" 
+BSC32=bscmake.exe
+BSC32_FLAGS=/nologo /o"$(OUTDIR)\Gvim_vc5.bsc" 
+BSC32_SBRS= \
+	
+LINK32=link.exe
+LINK32_FLAGS=libcd.lib oldnames.lib kernel32.lib user32.lib gdi32.lib\
+ winspool.lib comdlg32.lib advapi32.lib shell32.lib imm32.lib /nologo\
+ /subsystem:windows /profile /debug /machine:I386 /nodefaultlib\
+ /out:".\gvimrwd.exe" 
+LINK32_OBJS= \
+	"$(INTDIR)\buffer.obj" \
+	"$(INTDIR)\charset.obj" \
+	"$(INTDIR)\digraph.obj" \
+	"$(INTDIR)\edit.obj" \
+	"$(INTDIR)\eval.obj" \
+	"$(INTDIR)\ex_cmds.obj" \
+	"$(INTDIR)\ex_docmd.obj" \
+	"$(INTDIR)\ex_getln.obj" \
+	"$(INTDIR)\fileio.obj" \
+	"$(INTDIR)\getchar.obj" \
+	"$(INTDIR)\gui.obj" \
+	"$(INTDIR)\gui_w32.obj" \
+	"$(INTDIR)\hangul.obj" \
+	"$(INTDIR)\main.obj" \
+	"$(INTDIR)\mark.obj" \
+	"$(INTDIR)\memfile.obj" \
+	"$(INTDIR)\memline.obj" \
+	"$(INTDIR)\message.obj" \
+	"$(INTDIR)\misc1.obj" \
+	"$(INTDIR)\misc2.obj" \
+	"$(INTDIR)\normal.obj" \
+	"$(INTDIR)\ops.obj" \
+	"$(INTDIR)\option.obj" \
+	"$(INTDIR)\os_w32exe.obj" \
+	"$(INTDIR)\os_win32.obj" \
+	"$(INTDIR)\quickfix.obj" \
+	"$(INTDIR)\regexp.obj" \
+	"$(INTDIR)\screen.obj" \
+	"$(INTDIR)\search.obj" \
+	"$(INTDIR)\syntax.obj" \
+	"$(INTDIR)\tag.obj" \
+	"$(INTDIR)\term.obj" \
+	"$(INTDIR)\ui.obj" \
+	"$(INTDIR)\undo.obj" \
+	"$(INTDIR)\version.obj" \
+	"$(INTDIR)\vim.res" \
+	"$(INTDIR)\window.obj" \
+	"$(INTDIR)\winime.obj"
+
+".\gvimrwd.exe" : "$(OUTDIR)" $(DEF_FILE) $(LINK32_OBJS)
+    $(LINK32) @<<
+  $(LINK32_FLAGS) $(LINK32_OBJS)
+<<
+
+!ENDIF 
+
+
+!IF "$(CFG)" == "Vim - Win32 Release" || "$(CFG)" == "Vim - Win32 Debug" ||\
+ "$(CFG)" == "Vim - Win32 Release with Debug"
+SOURCE=.\buffer.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_BUFFE=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\buffer.obj" : $(SOURCE) $(DEP_CPP_BUFFE) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_BUFFE=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\buffer.obj"	"$(INTDIR)\buffer.sbr" : $(SOURCE) $(DEP_CPP_BUFFE)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_BUFFE=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_BUFFE=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\buffer.obj" : $(SOURCE) $(DEP_CPP_BUFFE) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\charset.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_CHARS=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\charset.obj" : $(SOURCE) $(DEP_CPP_CHARS) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_CHARS=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\charset.obj"	"$(INTDIR)\charset.sbr" : $(SOURCE) $(DEP_CPP_CHARS)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_CHARS=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_CHARS=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\charset.obj" : $(SOURCE) $(DEP_CPP_CHARS) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\digraph.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_DIGRA=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\digraph.obj" : $(SOURCE) $(DEP_CPP_DIGRA) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_DIGRA=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\digraph.obj"	"$(INTDIR)\digraph.sbr" : $(SOURCE) $(DEP_CPP_DIGRA)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_DIGRA=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_DIGRA=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\digraph.obj" : $(SOURCE) $(DEP_CPP_DIGRA) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\edit.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_EDIT_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	".\winime.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\edit.obj" : $(SOURCE) $(DEP_CPP_EDIT_) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_EDIT_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	".\winime.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\edit.obj"	"$(INTDIR)\edit.sbr" : $(SOURCE) $(DEP_CPP_EDIT_)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_EDIT_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	".\winime.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_EDIT_=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\edit.obj" : $(SOURCE) $(DEP_CPP_EDIT_) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\eval.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_EVAL_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\eval.obj" : $(SOURCE) $(DEP_CPP_EVAL_) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_EVAL_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\eval.obj"	"$(INTDIR)\eval.sbr" : $(SOURCE) $(DEP_CPP_EVAL_)\
+ "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_EVAL_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_EVAL_=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\eval.obj" : $(SOURCE) $(DEP_CPP_EVAL_) "$(INTDIR)"
+
+
+!ENDIF 
+
+SOURCE=.\ex_cmds.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_EX_CM=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\ex_cmds.obj" : $(SOURCE) $(DEP_CPP_EX_CM) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_EX_CM=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\ex_cmds.obj"	"$(INTDIR)\ex_cmds.sbr" : $(SOURCE) $(DEP_CPP_EX_CM)\
+ "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_EX_CM=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_EX_CM=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\ex_cmds.obj" : $(SOURCE) $(DEP_CPP_EX_CM) "$(INTDIR)"
+
+
+!ENDIF 
+
+SOURCE=.\ex_docmd.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_EX_DO=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\ex_docmd.obj" : $(SOURCE) $(DEP_CPP_EX_DO) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_EX_DO=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\ex_docmd.obj"	"$(INTDIR)\ex_docmd.sbr" : $(SOURCE) $(DEP_CPP_EX_DO)\
+ "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_EX_DO=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_EX_DO=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\ex_docmd.obj" : $(SOURCE) $(DEP_CPP_EX_DO) "$(INTDIR)"
+
+
+!ENDIF 
+
+SOURCE=.\ex_getln.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_EX_GE=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\ex_getln.obj" : $(SOURCE) $(DEP_CPP_EX_GE) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_EX_GE=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\ex_getln.obj"	"$(INTDIR)\ex_getln.sbr" : $(SOURCE) $(DEP_CPP_EX_GE)\
+ "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_EX_GE=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_EX_GE=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\ex_getln.obj" : $(SOURCE) $(DEP_CPP_EX_GE) "$(INTDIR)"
+
+
+!ENDIF 
+
+SOURCE=.\fileio.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_FILEI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\fileio.obj" : $(SOURCE) $(DEP_CPP_FILEI) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_FILEI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\fileio.obj"	"$(INTDIR)\fileio.sbr" : $(SOURCE) $(DEP_CPP_FILEI)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_FILEI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_FILEI=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\fileio.obj" : $(SOURCE) $(DEP_CPP_FILEI) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\getchar.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_GETCH=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\getchar.obj" : $(SOURCE) $(DEP_CPP_GETCH) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_GETCH=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\getchar.obj"	"$(INTDIR)\getchar.sbr" : $(SOURCE) $(DEP_CPP_GETCH)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_GETCH=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_GETCH=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\getchar.obj" : $(SOURCE) $(DEP_CPP_GETCH) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\gui.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_GUI_C=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\gui.obj" : $(SOURCE) $(DEP_CPP_GUI_C) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_GUI_C=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\gui.obj"	"$(INTDIR)\gui.sbr" : $(SOURCE) $(DEP_CPP_GUI_C)\
+ "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_GUI_C=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_GUI_C=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\gui.obj" : $(SOURCE) $(DEP_CPP_GUI_C) "$(INTDIR)"
+
+
+!ENDIF 
+
+SOURCE=.\gui_w32.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_GUI_W=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	".\winime.h"\
+	
+
+"$(INTDIR)\gui_w32.obj" : $(SOURCE) $(DEP_CPP_GUI_W) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_GUI_W=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	".\winime.h"\
+	
+
+"$(INTDIR)\gui_w32.obj"	"$(INTDIR)\gui_w32.sbr" : $(SOURCE) $(DEP_CPP_GUI_W)\
+ "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_GUI_W=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	".\winime.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_GUI_W=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\gui_w32.obj" : $(SOURCE) $(DEP_CPP_GUI_W) "$(INTDIR)"
+
+
+!ENDIF 
+
+SOURCE=.\hangul.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_HANGU=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	".\winime.h"\
+	
+
+"$(INTDIR)\hangul.obj" : $(SOURCE) $(DEP_CPP_HANGU) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_HANGU=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	".\winime.h"\
+	
+
+"$(INTDIR)\hangul.obj"	"$(INTDIR)\hangul.sbr" : $(SOURCE) $(DEP_CPP_HANGU)\
+ "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_HANGU=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	".\winime.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_HANGU=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\hangul.obj" : $(SOURCE) $(DEP_CPP_HANGU) "$(INTDIR)"
+
+
+!ENDIF 
+
+SOURCE=.\main.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_MAIN_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.c"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\main.obj" : $(SOURCE) $(DEP_CPP_MAIN_) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_MAIN_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.c"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\main.obj"	"$(INTDIR)\main.sbr" : $(SOURCE) $(DEP_CPP_MAIN_)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_MAIN_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.c"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_MAIN_=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\main.obj" : $(SOURCE) $(DEP_CPP_MAIN_) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\mark.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_MARK_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\mark.obj" : $(SOURCE) $(DEP_CPP_MARK_) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_MARK_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\mark.obj"	"$(INTDIR)\mark.sbr" : $(SOURCE) $(DEP_CPP_MARK_)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_MARK_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_MARK_=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\mark.obj" : $(SOURCE) $(DEP_CPP_MARK_) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\memfile.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_MEMFI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\memfile.obj" : $(SOURCE) $(DEP_CPP_MEMFI) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_MEMFI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\memfile.obj"	"$(INTDIR)\memfile.sbr" : $(SOURCE) $(DEP_CPP_MEMFI)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_MEMFI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_MEMFI=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\memfile.obj" : $(SOURCE) $(DEP_CPP_MEMFI) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\memline.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_MEMLI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\memline.obj" : $(SOURCE) $(DEP_CPP_MEMLI) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_MEMLI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\memline.obj"	"$(INTDIR)\memline.sbr" : $(SOURCE) $(DEP_CPP_MEMLI)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_MEMLI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_MEMLI=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\memline.obj" : $(SOURCE) $(DEP_CPP_MEMLI) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\message.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_MESSA=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\message.obj" : $(SOURCE) $(DEP_CPP_MESSA) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_MESSA=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\message.obj"	"$(INTDIR)\message.sbr" : $(SOURCE) $(DEP_CPP_MESSA)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_MESSA=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_MESSA=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\message.obj" : $(SOURCE) $(DEP_CPP_MESSA) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\misc1.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_MISC1=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\misc1.obj" : $(SOURCE) $(DEP_CPP_MISC1) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_MISC1=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\misc1.obj"	"$(INTDIR)\misc1.sbr" : $(SOURCE) $(DEP_CPP_MISC1)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_MISC1=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_MISC1=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\misc1.obj" : $(SOURCE) $(DEP_CPP_MISC1) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\misc2.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_MISC2=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\misc2.obj" : $(SOURCE) $(DEP_CPP_MISC2) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_MISC2=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\misc2.obj"	"$(INTDIR)\misc2.sbr" : $(SOURCE) $(DEP_CPP_MISC2)\
+ "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_MISC2=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_MISC2=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\misc2.obj" : $(SOURCE) $(DEP_CPP_MISC2) "$(INTDIR)"
+
+
+!ENDIF 
+
+SOURCE=.\normal.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_NORMA=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\normal.obj" : $(SOURCE) $(DEP_CPP_NORMA) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_NORMA=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\normal.obj"	"$(INTDIR)\normal.sbr" : $(SOURCE) $(DEP_CPP_NORMA)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_NORMA=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_NORMA=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\normal.obj" : $(SOURCE) $(DEP_CPP_NORMA) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\ops.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_OPS_C=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\ops.obj" : $(SOURCE) $(DEP_CPP_OPS_C) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_OPS_C=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\ops.obj"	"$(INTDIR)\ops.sbr" : $(SOURCE) $(DEP_CPP_OPS_C)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_OPS_C=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_OPS_C=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\ops.obj" : $(SOURCE) $(DEP_CPP_OPS_C) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\option.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_OPTIO=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\option.obj" : $(SOURCE) $(DEP_CPP_OPTIO) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_OPTIO=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\option.obj"	"$(INTDIR)\option.sbr" : $(SOURCE) $(DEP_CPP_OPTIO)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_OPTIO=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_OPTIO=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\option.obj" : $(SOURCE) $(DEP_CPP_OPTIO) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\os_w32exe.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_OS_W3=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\os_w32exe.obj" : $(SOURCE) $(DEP_CPP_OS_W3) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_OS_W3=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\os_w32exe.obj"	"$(INTDIR)\os_w32exe.sbr" : $(SOURCE)\
+ $(DEP_CPP_OS_W3) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_OS_W3=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_OS_W3=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\os_w32exe.obj" : $(SOURCE) $(DEP_CPP_OS_W3) "$(INTDIR)"
+
+
+!ENDIF 
+
+SOURCE=.\os_win32.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_OS_WI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\os_win32.obj" : $(SOURCE) $(DEP_CPP_OS_WI) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_OS_WI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\os_win32.obj"	"$(INTDIR)\os_win32.sbr" : $(SOURCE) $(DEP_CPP_OS_WI)\
+ "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_OS_WI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_OS_WI=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\os_win32.obj" : $(SOURCE) $(DEP_CPP_OS_WI) "$(INTDIR)"
+
+
+!ENDIF 
+
+SOURCE=.\quickfix.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_QUICK=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\quickfix.obj" : $(SOURCE) $(DEP_CPP_QUICK) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_QUICK=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\quickfix.obj"	"$(INTDIR)\quickfix.sbr" : $(SOURCE) $(DEP_CPP_QUICK)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_QUICK=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_QUICK=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\quickfix.obj" : $(SOURCE) $(DEP_CPP_QUICK) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\regexp.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_REGEX=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\regexp.obj" : $(SOURCE) $(DEP_CPP_REGEX) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_REGEX=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\regexp.obj"	"$(INTDIR)\regexp.sbr" : $(SOURCE) $(DEP_CPP_REGEX)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_REGEX=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_REGEX=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\regexp.obj" : $(SOURCE) $(DEP_CPP_REGEX) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\screen.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_SCREE=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\screen.obj" : $(SOURCE) $(DEP_CPP_SCREE) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_SCREE=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\screen.obj"	"$(INTDIR)\screen.sbr" : $(SOURCE) $(DEP_CPP_SCREE)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_SCREE=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\hangul.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_SCREE=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\screen.obj" : $(SOURCE) $(DEP_CPP_SCREE) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\search.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_SEARC=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\search.obj" : $(SOURCE) $(DEP_CPP_SEARC) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_SEARC=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\search.obj"	"$(INTDIR)\search.sbr" : $(SOURCE) $(DEP_CPP_SEARC)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_SEARC=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_SEARC=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\search.obj" : $(SOURCE) $(DEP_CPP_SEARC) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\syntax.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_SYNTA=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\syntax.obj" : $(SOURCE) $(DEP_CPP_SYNTA) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_SYNTA=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\syntax.obj"	"$(INTDIR)\syntax.sbr" : $(SOURCE) $(DEP_CPP_SYNTA)\
+ "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_SYNTA=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_SYNTA=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\syntax.obj" : $(SOURCE) $(DEP_CPP_SYNTA) "$(INTDIR)"
+
+
+!ENDIF 
+
+SOURCE=.\tag.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_TAG_C=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\tag.obj" : $(SOURCE) $(DEP_CPP_TAG_C) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_TAG_C=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\tag.obj"	"$(INTDIR)\tag.sbr" : $(SOURCE) $(DEP_CPP_TAG_C)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_TAG_C=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_TAG_C=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\tag.obj" : $(SOURCE) $(DEP_CPP_TAG_C) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\term.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_TERM_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\term.obj" : $(SOURCE) $(DEP_CPP_TERM_) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_TERM_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\term.obj"	"$(INTDIR)\term.sbr" : $(SOURCE) $(DEP_CPP_TERM_)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_TERM_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_TERM_=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\term.obj" : $(SOURCE) $(DEP_CPP_TERM_) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\ui.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_UI_C40=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\ui.obj" : $(SOURCE) $(DEP_CPP_UI_C40) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_UI_C40=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+
+"$(INTDIR)\ui.obj"	"$(INTDIR)\ui.sbr" : $(SOURCE) $(DEP_CPP_UI_C40) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_UI_C40=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_UI_C40=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\ui.obj" : $(SOURCE) $(DEP_CPP_UI_C40) "$(INTDIR)"
+
+
+!ENDIF 
+
+SOURCE=.\undo.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_UNDO_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\undo.obj" : $(SOURCE) $(DEP_CPP_UNDO_) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_UNDO_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\undo.obj"	"$(INTDIR)\undo.sbr" : $(SOURCE) $(DEP_CPP_UNDO_)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_UNDO_=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_UNDO_=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\undo.obj" : $(SOURCE) $(DEP_CPP_UNDO_) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\version.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_VERSI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\version.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\version.obj" : $(SOURCE) $(DEP_CPP_VERSI) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_VERSI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\version.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\version.obj"	"$(INTDIR)\version.sbr" : $(SOURCE) $(DEP_CPP_VERSI)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_VERSI=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\version.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_VERSI=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\version.obj" : $(SOURCE) $(DEP_CPP_VERSI) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\vim.rc
+DEP_RSC_VIM_R=\
+	".\vim.ico"\
+	
+
+"$(INTDIR)\vim.res" : $(SOURCE) $(DEP_RSC_VIM_R) "$(INTDIR)"
+	$(RSC) $(RSC_PROJ) $(SOURCE)
+
+
+SOURCE=.\window.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_WINDO=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /GX /O2 /I ".\proto" /D "NDEBUG" /D "WIN32" /D\
+ "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\window.obj" : $(SOURCE) $(DEP_CPP_WINDO) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_WINDO=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /Od /I ".\proto" /D "_DEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /FR"$(INTDIR)\\" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\"\
+ /FD /c 
+
+"$(INTDIR)\window.obj"	"$(INTDIR)\window.sbr" : $(SOURCE) $(DEP_CPP_WINDO)\
+ "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_WINDO=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_WINDO=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+CPP_SWITCHES=/nologo /MT /W3 /Gm /GX /Zi /O2 /I ".\proto" /D "NDEBUG" /D\
+ "WIN32" /D "USE_GUI_WIN32" /Fo"$(INTDIR)\\" /Fd"$(INTDIR)\\" /FD /c 
+
+"$(INTDIR)\window.obj" : $(SOURCE) $(DEP_CPP_WINDO) "$(INTDIR)"
+	$(CPP) @<<
+  $(CPP_SWITCHES) $(SOURCE)
+<<
+
+
+!ENDIF 
+
+SOURCE=.\winime.c
+
+!IF  "$(CFG)" == "Vim - Win32 Release"
+
+DEP_CPP_WINIM=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	".\winime.h"\
+	
+
+"$(INTDIR)\winime.obj" : $(SOURCE) $(DEP_CPP_WINIM) "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Debug"
+
+DEP_CPP_WINIM=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	".\winime.h"\
+	
+
+"$(INTDIR)\winime.obj"	"$(INTDIR)\winime.sbr" : $(SOURCE) $(DEP_CPP_WINIM)\
+ "$(INTDIR)"
+
+
+!ELSEIF  "$(CFG)" == "Vim - Win32 Release with Debug"
+
+DEP_CPP_WINIM=\
+	".\ascii.h"\
+	".\ex_cmds.h"\
+	".\farsi.h"\
+	".\feature.h"\
+	".\globals.h"\
+	".\gui.h"\
+	".\keymap.h"\
+	".\macros.h"\
+	".\option.h"\
+	".\os_dos.h"\
+	".\os_msdos.h"\
+	".\os_win32.h"\
+	".\proto.h"\
+	".\proto\buffer.pro"\
+	".\proto\charset.pro"\
+	".\proto\digraph.pro"\
+	".\proto\edit.pro"\
+	".\proto\eval.pro"\
+	".\proto\ex_cmds.pro"\
+	".\proto\ex_docmd.pro"\
+	".\proto\ex_getln.pro"\
+	".\proto\fileio.pro"\
+	".\proto\getchar.pro"\
+	".\proto\gui.pro"\
+	".\proto\gui_w32.pro"\
+	".\proto\if_ole.pro"\
+	".\proto\if_python.pro"\
+	".\proto\main.pro"\
+	".\proto\mark.pro"\
+	".\proto\memfile.pro"\
+	".\proto\memline.pro"\
+	".\proto\message.pro"\
+	".\proto\misc1.pro"\
+	".\proto\misc2.pro"\
+	".\proto\normal.pro"\
+	".\proto\ops.pro"\
+	".\proto\option.pro"\
+	".\proto\os_msdos.pro"\
+	".\proto\os_win32.pro"\
+	".\proto\quickfix.pro"\
+	".\proto\regexp.pro"\
+	".\proto\screen.pro"\
+	".\proto\search.pro"\
+	".\proto\syntax.pro"\
+	".\proto\tag.pro"\
+	".\proto\term.pro"\
+	".\proto\ui.pro"\
+	".\proto\undo.pro"\
+	".\proto\version.pro"\
+	".\proto\window.pro"\
+	".\regexp.h"\
+	".\structs.h"\
+	".\term.h"\
+	".\vim.h"\
+	".\winime.h"\
+	{$(INCLUDE)}"sys\stat.h"\
+	{$(INCLUDE)}"sys\types.h"\
+	
+NODEP_CPP_WINIM=\
+	".\config.h"\
+	".\gui_athena.pro"\
+	".\gui_beos.h"\
+	".\gui_beos.pro"\
+	".\gui_mac.pro"\
+	".\gui_motif.pro"\
+	".\gui_x11.pro"\
+	".\if_perl.pro"\
+	".\if_perlsfio.pro"\
+	".\if_sniff.h"\
+	".\os_amiga.h"\
+	".\os_amiga.pro"\
+	".\os_archie.h"\
+	".\os_beos.h"\
+	".\os_beos.pro"\
+	".\os_mac.h"\
+	".\os_mac.pro"\
+	".\os_mint.h"\
+	".\os_os2_cfg.h"\
+	".\os_unix.h"\
+	".\os_unix.pro"\
+	".\os_vms.h"\
+	".\os_vms.pro"\
+	".\osdef.h"\
+	".\termlib.pro"\
+	
+
+"$(INTDIR)\winime.obj" : $(SOURCE) $(DEP_CPP_WINIM) "$(INTDIR)"
+
+
+!ENDIF 
+
+
+!ENDIF 
+
diff -b -u -r -N ../vim-5.0/src/hangul.c src/hangul.c
--- ../vim-5.0/src/hangul.c	Thu Jan  1 09:00:00 1970
+++ src/hangul.c	Fri Feb 20 19:36:42 1998
@@ -0,0 +1,69 @@
+/*
+ *	file
+ */
+
+#include "vim.h"
+#include "globals.h"
+#include "proto.h"
+#include "option.h"
+#include "winime.h"
+#ifdef WIN32
+# include <windows.h>
+#endif
+
+
+int	h_is_correct( int col, char_u *ptr )
+{
+	int	i, k;
+	if( col==0 )	return(1);
+#ifdef WIN32
+        if ( IsDBCSLeadByte(*ptr) ) {
+#else
+	if( *ptr & 0x80 ){
+#endif
+		for( i=col, k=0 ; i>=0 && (*(ptr-k) & 0x80); k++,i-- );
+		return(k%2);
+	}
+	else	return(1);
+}
+
+int IsLeadByte(char_u c)
+{
+#ifdef WIN32
+    return IsDBCSLeadByte(c);
+#else
+    return (c & 0x80);
+#endif
+}
+
+int IsTrailByte( char *base, char *p )
+{
+    int lbc = 0;    /* lead byte count*/
+
+	if ( base >= p )
+		return 0;
+
+    while ( p > base ) {
+	if ( !IsLeadByte(*(--p)) )
+	    break;
+	lbc++;
+    }
+
+    return (lbc & 1);
+}
+
+
+int AdjustCursorForHangul(void) {
+
+    if ( curwin->w_cursor.col > 0 ) {
+        char_u *p;
+        p = ml_get(curwin->w_cursor.lnum);
+        if ( IsTrailByte(p, p + curwin->w_cursor.col ) ) {
+            --curwin->w_cursor.col;
+            return 1;
+        }
+    }
+
+    return 0;
+}
+       
diff -b -u -r -N ../vim-5.0/src/hangul.h src/hangul.h
--- ../vim-5.0/src/hangul.h	Thu Jan  1 09:00:00 1970
+++ src/hangul.h	Fri Feb 20 19:36:42 1998
@@ -0,0 +1,7 @@
+/*
+ *	Korean Checking Function
+ */
+int h_is_correct( int, char_u* );
+int AdjustCursorForHangul(void);
+int IsLeadByte(char_u c);
+int IsTrailByte( char *base, char *p );
diff -b -u -r -N ../vim-5.0/src/makefile.bcc src/makefile.bcc
--- ../vim-5.0/src/makefile.bcc	Thu Feb 19 10:00:56 1998
+++ src/makefile.bcc	Fri Feb 20 22:07:03 1998
@@ -69,7 +69,8 @@
  ui.obj \
  undo.obj \
  window.obj \
- version.obj
+ version.obj \
+ hangul.obj
 
 all: vim.exe ctags/ctags.exe xxd/xxd.exe
 
@@ -110,7 +111,8 @@
 ui.obj+
 undo.obj+
 window.obj+
-version.obj
+version.obj+
+hangul.obj+
 vim
 		# no map file
 fp87.lib+
@@ -203,6 +205,8 @@
 window.obj: window.c
 
 version.obj: version.c version.h
+
+hangul.obj : hangul.c hangul.h
 
 #		*Compiler Configuration File*
 # The following compile options can be changed for better machines.
diff -b -u -r -N ../vim-5.0/src/makefile.bor src/makefile.bor
--- ../vim-5.0/src/makefile.bor	Thu Feb 19 10:00:56 1998
+++ src/makefile.bor	Fri Feb 20 22:08:04 1998
@@ -266,7 +266,9 @@
 	$(OBJDIR)\ui.obj \
 	$(OBJDIR)\undo.obj \
 	$(OBJDIR)\version.obj \
-	$(OBJDIR)\window.obj
+	$(OBJDIR)\window.obj \
+	$(OBJDIR)\hangul.obj
+
 
 !if ($(OLE)==1)
 vimobj = $(vimobj) \
@@ -467,6 +469,8 @@
 $(OBJDIR)\os_msdos.obj:  os_msdos.c
 
 $(OBJDIR)\window.obj:  window.c
+
+$(OBJDIR)\hangul.obj:  hangul.c
 
 $(OBJDIR)\gui.obj: gui.c
 
diff -b -u -r -N ../vim-5.0/src/makefile.cyg src/makefile.cyg
--- ../vim-5.0/src/makefile.cyg	Thu Feb 19 10:00:56 1998
+++ src/makefile.cyg	Fri Feb 20 22:09:03 1998
@@ -52,6 +52,7 @@
 	obj/ui.o \
 	obj/undo.o \
 	obj/window.o \
+	obj/hangul.o \
 	$(TERMLIB)
 
 all: vim.exe ctags/ctags.exe xxd/xxd.exe
@@ -176,3 +177,6 @@
 
 obj/window.o:	window.c $(INCL)
 	$(CC) -c $(CFLAGS) window.c -o obj/window.o
+
+obj/hangul.o:	hangul.h $(INCL)
+	$(CC) -c $(CFLAGS) hangul.c -o obj/hangul.o
\ No newline at end of file
diff -b -u -r -N ../vim-5.0/src/makefile.djg src/makefile.djg
--- ../vim-5.0/src/makefile.djg	Thu Feb 19 10:00:56 1998
+++ src/makefile.djg	Fri Feb 20 22:09:39 1998
@@ -50,6 +50,7 @@
 	obj/ui.o \
 	obj/undo.o \
 	obj/window.o \
+	obj/hangul.o \
 	$(TERMLIB)
 
 all: vim.exe ctags/ctags.exe xxd/xxd.exe
@@ -179,3 +180,6 @@
 
 obj/window.o:	window.c $(INCL)
 	$(CC) -c $(CFLAGS) window.c -o obj/window.o
+
+obj/hangul.o:	hangul.c $(INCL)
+	$(CC) -c $(CFLAGS) hangul.c -o obj/hangul.o
diff -b -u -r -N ../vim-5.0/src/makefile.dos src/makefile.dos
--- ../vim-5.0/src/makefile.dos	Thu Feb 19 10:00:56 1998
+++ src/makefile.dos	Fri Feb 20 22:10:33 1998
@@ -51,6 +51,7 @@
 	ui.c \
 	undo.c \
 	window.c \
+	hangul.c \
 	version.c
 
 OBJ =	objects/buffer.obj \
@@ -84,6 +85,7 @@
 	objects/ui.obj \
 	objects/undo.obj \
 	objects/window.obj \
+	objects/hangul.obj \
 	$(TERMLIB)
 
 vim.exe: $(OBJ) version.c version.h
@@ -190,3 +192,6 @@
 
 objects/window.obj:	window.c  $(INCL)
 	$(CC) $(CFLAGS) window.c -o objects/window.obj
+
+objects/hangul.obj:	hangul.c  $(INCL)
+	$(CC) $(CFLAGS) hangul.c -o objects/hangul.obj
diff -b -u -r -N ../vim-5.0/src/makefile.w32 src/makefile.w32
--- ../vim-5.0/src/makefile.w32	Thu Feb 19 10:00:56 1998
+++ src/makefile.w32	Fri Feb 20 22:11:20 1998
@@ -144,6 +144,7 @@
 	$(OUTDIR)\ui.obj \
 	$(OUTDIR)\undo.obj \
 	$(OUTDIR)\window.obj \
+	$(OUTDIR)\hangul.obj \
 	$(OUTDIR)\vim.res
 
 # PYTHON interface
@@ -298,6 +299,9 @@
 
 $(OUTDIR)/window.obj:	$(OUTDIR) window.c  $(INCL)
 	$(CC) $(CFLAGS) window.c /Fo$(OUTDIR)/window.obj $(PDB)
+
+$(OUTDIR)/hangul.obj:	$(OUTDIR) hangul.c  $(INCL)
+	$(CC) $(CFLAGS) hangul.c /Fo$(OUTDIR)/hangul.obj $(PDB)
 
 $(OUTDIR)/vim.res:	$(OUTDIR) vim.rc version.h
 	$(RC) /l 0x409 /Fo$(OUTDIR)/vim.res $(RCFLAGS) vim.rc
diff -b -u -r -N ../vim-5.0/src/misc1.c src/misc1.c
--- ../vim-5.0/src/misc1.c	Thu Feb 19 04:27:31 1998
+++ src/misc1.c	Fri Feb 20 20:12:42 1998
@@ -11,6 +11,7 @@
  */
 
 #include "vim.h"
+#include "hangul.h"
 
 #ifdef HAVE_FCNTL_H
 # include <fcntl.h>		/* for chdir() */
@@ -1153,6 +1154,11 @@
 del_char(fixpos)
     int		fixpos;
 {
+    /* begin hangul*/
+    if( AdjustCursorForHangul() ) {
+        return del_chars(2L, fixpos);
+    }
+    else /* end hangul */
     return del_chars(1L, fixpos);
 }
 
diff -b -u -r -N ../vim-5.0/src/misc2.c src/misc2.c
--- ../vim-5.0/src/misc2.c	Mon Jan 26 04:27:59 1998
+++ src/misc2.c	Fri Feb 20 20:56:55 1998
@@ -11,6 +11,7 @@
  */
 
 #include "vim.h"
+#include "hangul.h"
 
 /*
  * coladvance(col)
@@ -48,6 +49,9 @@
 	curwin->w_cursor.col = 0;
     else
 	curwin->w_cursor.col = idx;
+    
+    AdjustCursorForHangul(); /*hangul*/
+
     if (col <= wcol)
 	return FAIL;	    /* Couldn't reach column */
     else
@@ -74,6 +78,10 @@
 
     if (*p != NUL)	/* still within line, move to next char (may be NUL) */
     {
+        /* begin hangul */
+        if ( IsLeadByte(p[0]) && p[1] != NUL )
+            lp->col += 2; /* two byte character ( hangul ) */
+        else /* end hangul */
 	lp->col++;
 	return ((p[1] != NUL) ? 0 : 1);
     }
@@ -99,6 +107,39 @@
 	r = inc(lp);
     return r;
 }
+/* hangul start */
+
+    int
+han_dec(lp)
+    FPOS  *lp;
+{
+    char_u *p = ml_get(lp->lnum);
+    
+    if (lp->col > 0)
+    {		/* still within line */
+	lp->col--;
+        if ( lp->col > 0 && IsTrailByte(p,p+lp->col))
+            lp->col--;
+        return 0;
+    }
+    if (lp->lnum > 1)
+    {		/* there is a prior line */
+	lp->lnum--;
+	lp->col = STRLEN(ml_get(lp->lnum));
+        if ( lp->col > 0 && IsTrailByte(p,p+lp->col))
+            lp->col--;
+	return 1;
+    }
+    return -1;			/* at start of file */
+}
+
+    int
+han_dec_cursor()
+{
+    return han_dec(&curwin->w_cursor);
+}
+
+/* hangul end */
 
 /*
  * dec(p)
diff -b -u -r -N ../vim-5.0/src/normal.c src/normal.c
--- ../vim-5.0/src/normal.c	Sun Feb  8 06:29:34 1998
+++ src/normal.c	Fri Feb 20 22:48:54 1998
@@ -12,6 +12,7 @@
  */
 
 #include "vim.h"
+#include "hangul.h"
 
 /*
  * The Visual area is remembered for reselection.
@@ -1254,6 +1255,9 @@
 	    && stuff_empty()
 	    && oap->regname == 0)
 	(void)edit(restart_edit, FALSE, 1L);
+
+    AdjustCursorForHangul(); /* hangul */
+
 }
 
 /*
@@ -1370,6 +1374,13 @@
 	    oap->end = oap->start;
 	    oap->start = curwin->w_cursor;
 	}
+        /* begin hangul */
+        if ( VIsual_active ) {
+            char_u *p;
+            p = ml_get(oap->end.lnum);
+            if ( IsTrailByte(p,p+oap->end.col+1) )
+                oap->end.col++;
+        } /* end hangul */
 	oap->line_count = oap->end.lnum - oap->start.lnum + 1;
 
 	if (VIsual_active || redo_VIsual_busy)
diff -b -u -r -N ../vim-5.0/src/ops.c src/ops.c
--- ../vim-5.0/src/ops.c	Thu Feb 19 05:56:49 1998
+++ src/ops.c	Fri Feb 20 23:18:39 1998
@@ -12,6 +12,7 @@
  */
 
 #include "vim.h"
+#include "hangul.h"
 
 /*
  * Number of registers.
@@ -962,6 +963,7 @@
     }
     else if (oap->line_count == 1)	/* delete characters within one line */
     {
+        char_u *p; /* hangul */
 	if (u_save_cursor() == FAIL)
 	    return FAIL;
 	    /* if 'cpoptions' contains '$', display '$' at end of change */
@@ -971,6 +973,11 @@
 		&& !oap->is_VIsual)
 	    display_dollar(oap->end.col - !oap->inclusive);
 	n = oap->end.col - oap->start.col + 1 - !oap->inclusive;
+        /* begin hangul */
+        p = ml_get(oap->end.lnum);
+        if ( strlen(p) == oap->end.col + 2 && IsTrailByte(p,p+oap->end.col+1))
+            n++; /*  ڰ ѱ̰  ڸ ﶧ*/
+        /* end hangul */
 	(void)del_chars((long)n, TRUE);
     }
     else				/* delete characters between lines */
@@ -1479,6 +1486,7 @@
     struct block_def bd;
     char_u	*insert_string = NULL;
     int		allocated = FALSE;
+    int         bMultiByteCode=0;   /* hangul */
 
 #ifdef USE_CLIPBOARD
     if (regname == '*')
@@ -1489,8 +1497,24 @@
 	orig_indent = get_indent();
 
     curbuf->b_op_start = curwin->w_cursor;	/* default for '[ mark */
+
+    /* begin hangul
+    ѱ ڿ put Ҷ
     if (dir == FORWARD)
+	curbuf->b_op_start.col++; */
+    if (dir == FORWARD) {
+        char_u *p = ml_get(curwin->w_cursor.lnum);
+        if ( p!=NULL ) {
+            p += curwin->w_cursor.col;
+            if ( IsLeadByte(*p) && (*(p+1) != '\0') ) {
+                bMultiByteCode = 1;
+                curbuf->b_op_start.col++; /* hangul */
+            }
+        }
 	curbuf->b_op_start.col++;
+    }
+    /* end hangul */
+
     curbuf->b_op_end = curwin->w_cursor;	/* default for '] mark */
 
     /*
@@ -1569,8 +1593,12 @@
 	if (dir == FORWARD && gchar_cursor() != NUL)
 	{
 	    getvcol(curwin, &curwin->w_cursor, NULL, NULL, &col);
-	    ++col;
-	    ++curwin->w_cursor.col;
+            
+            /* begin hangul */
+            /*  ++col;  ++curwin->w_cursor.col; */
+            col += bMultiByteCode + 1;
+            curwin->w_cursor.col += bMultiByteCode + 1;
+            /* end hangul */
 	}
 	else
 	    getvcol(curwin, &curwin->w_cursor, &col, NULL, NULL);
@@ -1653,12 +1681,20 @@
     /* if type is MCHAR, FORWARD is the same as BACKWARD on the next char */
 	    if (dir == FORWARD && gchar_cursor() != NUL)
 	    {
+                /* begin hangul
 		++col;
 		if (yanklen)
 		{
 		    ++curwin->w_cursor.col;
 		    ++curbuf->b_op_end.col;
+		} */
+                col += bMultiByteCode + 1;
+		if (yanklen)
+		{
+		    curwin->w_cursor.col += bMultiByteCode + 1;
+		    curbuf->b_op_end.col += bMultiByteCode + 1;
 		}
+		/* hangul end */
 	    }
 	    new_cursor = curwin->w_cursor;
 	}
diff -b -u -r -N ../vim-5.0/src/proto/gui.pro src/proto/gui.pro
--- ../vim-5.0/src/proto/gui.pro	Thu Feb 19 06:42:13 1998
+++ src/proto/gui.pro	Fri Feb 20 19:54:59 1998
@@ -43,3 +43,4 @@
 void gui_new_scrollbar_colors __ARGS((void));
 char_u *parse_guicursor __ARGS((void));
 void gui_focus_change __ARGS((int in_focus));
+void DisplayCompString __ARGS((char_u *s, int len));
diff -b -u -r -N ../vim-5.0/src/proto/misc2.pro src/proto/misc2.pro
--- ../vim-5.0/src/proto/misc2.pro	Thu Feb 19 06:41:57 1998
+++ src/proto/misc2.pro	Fri Feb 20 21:07:32 1998
@@ -5,6 +5,8 @@
 int incl __ARGS((FPOS *lp));
 int dec_cursor __ARGS((void));
 int dec __ARGS((FPOS *lp));
+int han_dec_cursor __ARGS((void));
+int han_dec __ARGS((FPOS *lp));
 int decl __ARGS((FPOS *lp));
 void check_cursor_lnum __ARGS((void));
 void adjust_cursor __ARGS((void));
diff -b -u -r -N ../vim-5.0/src/resource.h src/resource.h
--- ../vim-5.0/src/resource.h	Thu Jan  1 09:00:00 1970
+++ src/resource.h	Fri Feb 20 21:47:34 1998
@@ -0,0 +1,16 @@
+//{{NO_DEPENDENCIES}}
+// Microsoft Developer Studio generated include file.
+// Used by vim.rc
+//
+#define IDR_VIM                         101
+
+// Next default values for new objects
+// 
+#ifdef APSTUDIO_INVOKED
+#ifndef APSTUDIO_READONLY_SYMBOLS
+#define _APS_NEXT_RESOURCE_VALUE        102
+#define _APS_NEXT_COMMAND_VALUE         40001
+#define _APS_NEXT_CONTROL_VALUE         1000
+#define _APS_NEXT_SYMED_VALUE           101
+#endif
+#endif
diff -b -u -r -N ../vim-5.0/src/screen.c src/screen.c
--- ../vim-5.0/src/screen.c	Mon Feb 16 04:41:00 1998
+++ src/screen.c	Fri Feb 20 21:38:58 1998
@@ -11,6 +11,7 @@
  */
 
 #include "vim.h"
+#include "hangul.h"
 
 /*
  * The attributes that are actually active for writing to the screen.
@@ -962,6 +963,8 @@
     char_u	    *search_hl_start = NULL;
     char_u	    *search_hl_end = NULL;
 #endif
+    int             bCharacter = 0; /* hangul */
+    char_u          *line_head; /* hangul */
 
     if (startrow > endrow)		/* past the end already! */
 	return startrow;
@@ -1078,6 +1081,7 @@
 #endif
 #ifdef SYNTAX_HL
     line = ptr;
+    line_head = ptr; /*hangul*/
     rcol = 0;
 #endif
 
@@ -1278,6 +1282,7 @@
 	    else
 	    {
 		c = *ptr++;
+                bCharacter = 1; /* hangul */
 
 		if (has_syn_or_lbr)
 		{
@@ -1451,6 +1456,23 @@
 #endif
 	}
 
+        /* begin hangul */
+        if ( col == 0 && bCharacter ) {
+            if ( IsTrailByte(line_head, ptr-1) )
+                c='~';
+        }
+      	if (
+#ifdef RIGHTLEFT
+	    wp->w_p_rl ? (col <= 0) :
+#endif
+        (col >= Columns-1) )  {
+            if ( bCharacter && IsLeadByte(*(ptr-1)) && IsTrailByte(line_head, ptr) ) {
+                c = '~';                
+            }
+        }
+	bCharacter = 0;
+        /* end hangul*/
+
 	/*
 	 * Store the character.
 	 */
@@ -1536,9 +1558,20 @@
     while (col < endcol)
 #endif
     {
-	if (force || *screenp_from != *screenp_to ||
+        /* begin hangul ¿ ũ Ҷ win32 gui ڰ  ذ*/
+	/* if ( force || *screenp_from != *screenp_to ||
 		*(screenp_from + Columns) != *(screenp_to + Columns))
-	{
+	{*/
+       	if (
+#ifdef USE_GUI_WIN32
+            1 
+#else
+            force || *screenp_from != *screenp_to ||
+	    *(screenp_from + Columns) != *(screenp_to + Columns)
+#endif  
+	) {
+        /* end hangul */
+
 	    /*
 	     * Special handling when 'xs' termcap flag set (hpterm):
 	     * Attributes for characters are stored at the position where the
@@ -4946,7 +4979,7 @@
     int		col;
     static char	*(lines[]) =
     {
-	"VIM - Vi IMproved",
+	"VIM - Vi IMproved (hangul 1.0.2.20)",
 	"",
 	"version ",
 	"by Bram Moolenaar et al.",
diff -b -u -r -N ../vim-5.0/src/search.c src/search.c
--- ../vim-5.0/src/search.c	Mon Feb 16 05:22:12 1998
+++ src/search.c	Fri Feb 20 21:05:07 1998
@@ -1977,7 +1977,7 @@
     while (--count >= 0)
     {
 	sclass = cls();
-	if (dec_cursor() == -1)	    /* started at start of file */
+	if (han_dec_cursor() == -1)/*hangul*/ /* started at start of file */
 	    return FAIL;
 
 	if (!stop || sclass == cls() || sclass == 0)
@@ -1992,7 +1992,7 @@
 					     lineempty(curwin->w_cursor.lnum))
 		    goto finished;
 
-		if (dec_cursor() == -1)	    /* hit start of file, stop here */
+		if (han_dec_cursor() == -1)/*hangul*/ /* hit start of file, stop here */
 		    return OK;
 	    }
 
@@ -2074,7 +2074,7 @@
 	    if (skip_chars(cls(), FORWARD))
 		return FAIL;
 	}
-	dec_cursor();			/* overshot - one char backward */
+	han_dec_cursor(); /*hangul*/ /* overshot - one char backward */
 finished:
 	stop = FALSE;			/* we move only one word less */
     }
@@ -2101,7 +2101,7 @@
     while (--count >= 0)
     {
 	sclass = cls();
-	if ((i = dec_cursor()) == -1)
+	if ((i = han_dec_cursor()) == -1) /* hangul*/
 	    return FAIL;
 	if (eol && i == 1)
 	    return OK;
@@ -2112,7 +2112,7 @@
 	if (sclass != 0)
 	{
 	    while (cls() == sclass)
-		if ((i = dec_cursor()) == -1 || (eol && i == 1))
+		if ((i = han_dec_cursor()) == -1 || (eol && i == 1)) /*hangul*/
 		    return OK;
 	}
 
@@ -2123,7 +2123,7 @@
 	{
 	    if (curwin->w_cursor.col == 0 && lineempty(curwin->w_cursor.lnum))
 		break;
-	    if ((i = dec_cursor()) == -1 || (eol && i == 1))
+	    if ((i = han_dec_cursor()) == -1 || (eol && i == 1))/*hangul*/
 		return OK;
 	}
     }
@@ -2140,7 +2140,9 @@
     int	    dir;
 {
     while (cls() == cclass)
-	if ((dir == FORWARD ? inc_cursor() : dec_cursor()) == -1)
+	/*if ((dir == FORWARD ? inc_cursor() : dec_cursor()) == -1) */
+        /* hangul */
+        if ((dir == FORWARD ? inc_cursor() : han_dec_cursor()) == -1) 
 	    return TRUE;
     return FALSE;
 }
diff -b -u -r -N ../vim-5.0/src/term.c src/term.c
--- ../vim-5.0/src/term.c	Wed Feb 18 23:11:29 1998
+++ src/term.c	Fri Feb 20 20:49:29 1998
@@ -711,6 +711,13 @@
     {(int)KS_MD,	"\033[1m"},
     {(int)KS_UE,	"\033[m"},
     {(int)KS_US,	"\033[4m"},
+    /* start hangul */
+    {(int)KS_CCO,   "8"},
+    {(int)KS_CAF,   "\033[3%p1%dm"},
+    {(int)KS_CAB,   "\033[4%p1%dm"},
+    {(int)KS_CSF,   "\033[3%p1%dm"},
+    {(int)KS_CSB,   "\033[4%p1%dm"},
+    /* end hangul */
     {(int)KS_MS,	"y"},
     {(int)KS_LE,	"\010"},
 #  ifdef TERMINFO
@@ -1187,6 +1194,7 @@
 				{KS_BC, "bc"}, {KS_CSB,"Sb"}, {KS_CSF,"Sf"},
 				{KS_CAB,"AB"}, {KS_CAF,"AF"}, {KS_LE, "le"},
 				{KS_ND, "nd"}, {KS_OP, "op"},
+                                {KS_CCO, "Co"}, /* hangul : 1 line */
 				{0, NULL}
 			    };
 
diff -b -u -r -N ../vim-5.0/src/vim.rc src/vim.rc
--- ../vim-5.0/src/vim.rc	Thu Feb 19 10:01:20 1998
+++ src/vim.rc	Fri Feb 20 21:48:43 1998
@@ -1,74 +1,114 @@
-// vim:ts=8:sw=4:sts=4:
+//Microsoft Developer Studio generated resource script.
 //
-// VIM - Vi IMproved	by Bram Moolenaar
+#include "resource.h"
+
+#define APSTUDIO_READONLY_SYMBOLS
+/////////////////////////////////////////////////////////////////////////////
+//
+// Generated from the TEXTINCLUDE 2 resource.
 //
-// Do ":help uganda"  in Vim to read copying and usage conditions.
-// Do ":help credits" in Vim to see a list of people who contributed.
+#include "afxres.h"
 
-// vim.rc
-//   Icon and version information for the Win32 version of Vim
-//   Must be in DOS format <CR><NL>!
+/////////////////////////////////////////////////////////////////////////////
+#undef APSTUDIO_READONLY_SYMBOLS
 
-#include <winver.h>
-#include "version.h"
+/////////////////////////////////////////////////////////////////////////////
+// Korean resources
 
+#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_KOR)
+#ifdef _WIN32
+LANGUAGE LANG_KOREAN, SUBLANG_DEFAULT
+#pragma code_page(949)
+#endif //_WIN32
+
+#ifdef APSTUDIO_INVOKED
+/////////////////////////////////////////////////////////////////////////////
 //
-// Icon
+// TEXTINCLUDE
 //
-IDR_VIM ICON "VIM.ICO"
 
+1 TEXTINCLUDE DISCARDABLE 
+BEGIN
+    "resource.h\0"
+END
+
+2 TEXTINCLUDE DISCARDABLE 
+BEGIN
+    "#include ""afxres.h""\r\n"
+    "\0"
+END
+
+3 TEXTINCLUDE DISCARDABLE 
+BEGIN
+    "\r\n"
+    "\0"
+END
+
+#endif    // APSTUDIO_INVOKED
+
+
+/////////////////////////////////////////////////////////////////////////////
 //
-// Type Library
+// Icon
 //
-#ifdef HAVE_OLE
- 1 TYPELIB "VIM.TLB"
-#endif
 
+// Icon with lowest ID value placed first to ensure application icon
+// remains consistent on all systems.
+IDR_VIM                 ICON    DISCARDABLE     "vim.ico"
+
+#ifndef _MAC
+/////////////////////////////////////////////////////////////////////////////
 //
 // Version
 //
 
 VS_VERSION_INFO		VERSIONINFO
-  FILEVERSION		VIM_VERSION_MAJOR,VIM_VERSION_MINOR,VIM_VERSION_BUILD,VIM_VERSION_PATCHLEVEL
-  PRODUCTVERSION	VIM_VERSION_MAJOR,VIM_VERSION_MINOR,VIM_VERSION_BUILD,VIM_VERSION_PATCHLEVEL
-  FILEFLAGSMASK		VS_FFI_FILEFLAGSMASK
-
-#if VIM_VERSION_PATCHLEVEL > 0
- #ifdef _DEBUG
-  FILEFLAGS		VS_FF_PRERELEASE | VS_FF_DEBUG | VS_FF_PATCHED
- #else
-  FILEFLAGS		VS_FF_PRERELEASE | VS_FF_PATCHED
- #endif
+ FILEVERSION 5,0,25,2
+ PRODUCTVERSION 5,0,25,2
+ FILEFLAGSMASK 0x3fL
+#ifdef _DEBUG
+ FILEFLAGS 0x1L
 #else
- #ifdef _DEBUG
-  FILEFLAGS		VS_FF_PRERELEASE | VS_FF_DEBUG
- #else
-  FILEFLAGS		VS_FF_PRERELEASE
- #endif
+ FILEFLAGS 0x0L
 #endif
-
-  FILEOS		VOS__WINDOWS32
-  FILETYPE		VFT_APP
+ FILEOS 0x40004L
+ FILETYPE 0x1L
   FILESUBTYPE		0x0L
 BEGIN
   BLOCK "StringFileInfo"
   BEGIN
-    // 0x0409 == U.S. English; 0x04E4 => Windows Multilingual
-    BLOCK "040904E4"
+        BLOCK "041204b0"
     BEGIN
-	VALUE "CompanyName",		"Vim Developers\0"
-	VALUE "FileDescription",	"Vi Improved - A Text Editor\0"
-	VALUE "FileVersion",		VIM_VERSION_MAJOR_STR ", " VIM_VERSION_MINOR_STR ", " VIM_VERSION_BUILD_STR ", " VIM_VERSION_PATCHLEVEL_STR  "\0"
-	VALUE "InternalName",		"VIM\0"
-	VALUE "LegalCopyright",		"Copyright \251 1996,1997\0"
-	VALUE "LegalTrademarks",	"\0"
-	VALUE "OriginalFilename",	"VIM.EXE\0"
-	VALUE "ProductName",		"Vim\0"
-	VALUE "ProductVersion",		VIM_VERSION_MAJOR_STR ", " VIM_VERSION_MINOR_STR ", " VIM_VERSION_BUILD_STR ", " VIM_VERSION_PATCHLEVEL_STR "\0"
+            VALUE "CompanyName", "KAIST\0"
+            VALUE "FileDescription", "gvim\0"
+            VALUE "FileVersion", "5, 0, 25, 2\0"
+            VALUE "InternalName", "gvim\0"
+            VALUE "LegalCopyright", "Copyright  1998\0"
+            VALUE "OriginalFilename", "gvim.exe\0"
+            VALUE "ProductName", "KAIST gvim\0"
+            VALUE "ProductVersion", "5, 0, 25, 2\0"
     END
   END
   BLOCK "VarFileInfo"
   BEGIN
-	VALUE "Translation", 0x409, 0x4E4
+        VALUE "Translation", 0x412, 1200
   END
 END
+
+#endif    // !_MAC
+
+#endif    // Korean resources
+/////////////////////////////////////////////////////////////////////////////
+
+
+
+#ifndef APSTUDIO_INVOKED
+/////////////////////////////////////////////////////////////////////////////
+//
+// Generated from the TEXTINCLUDE 3 resource.
+//
+
+
+/////////////////////////////////////////////////////////////////////////////
+#endif    // not APSTUDIO_INVOKED
+
diff -b -u -r -N ../vim-5.0/src/winime.c src/winime.c
--- ../vim-5.0/src/winime.c	Thu Jan  1 09:00:00 1970
+++ src/winime.c	Fri Feb 20 19:36:33 1998
@@ -0,0 +1,280 @@
+
+#include <windows.h>
+#include <imm.h>
+#include "vim.h"
+#include "winime.h"
+
+extern void DisplayCompString(char_u *s,int len);
+
+
+static BOOL bKoreanMode = FALSE;
+extern HWND s_hwnd;
+static char lpCompStr[100];         // Pointer to composition str.
+static BOOL bInComposition=FALSE;
+static BOOL bCommandMode=TRUE;
+static BOOL bImeKorean=FALSE;
+
+
+void ImeSetOriginMode(void)
+{
+    HIMC    hImc;
+    DWORD   dwConvMode, dwSentMode;
+    if ( (  hImc = ImmGetContext( s_hwnd ) ) ) {
+        ImmGetConversionStatus(hImc, &dwConvMode, &dwSentMode);
+        if ( !(dwConvMode & IME_CMODE_NATIVE) && bKoreanMode == TRUE) {
+            ImmSimulateHotKey(s_hwnd, IME_KHOTKEY_ENGLISH);
+        }
+        else
+            bKoreanMode = FALSE;
+    }
+    bCommandMode = FALSE;
+}
+
+void ImeSetEnglishMode(void)
+{
+
+    HIMC    hImc;
+    DWORD   dwConvMode, dwSentMode;
+    if ( (  hImc = ImmGetContext( s_hwnd ) ) ) {
+        ImmGetConversionStatus(hImc, &dwConvMode, &dwSentMode);
+        if ( dwConvMode & IME_CMODE_NATIVE ) {
+            ImmSimulateHotKey(s_hwnd, IME_KHOTKEY_ENGLISH);
+            bKoreanMode = TRUE;
+        }
+        else
+            bKoreanMode = FALSE;
+    }
+    bCommandMode = TRUE;
+}
+
+void GetCompositionStr( HWND hwnd, LPARAM CompFlag )
+{
+     DWORD      dwBufLen;               // Stogare for len. of composition str
+
+     HIMC       hIMC;                   // Input context handle.
+
+     //
+     // If fail to get input context handle then do nothing.
+     // Applications should call ImmGetContext API to get
+     // input context handle.
+     //
+
+     if ( !( hIMC = ImmGetContext( hwnd ) ) )
+         return;
+
+     //
+     // Determines how much memory space to store the composition string.
+     // Applications should call ImmGetCompositionString with
+     // GCS_COMPSTR flag on, buffer length zero, to get the bullfer
+     // length.
+     //
+
+     if ( ( dwBufLen = ImmGetCompositionString( hIMC, GCS_COMPSTR, 
+                                         (void FAR*)NULL, 0l ) ) < 0 )
+         goto exit2;
+
+     if ( dwBufLen > 99 )
+         goto exit2;
+     //
+     // Reads in the composition string.
+     //
+     if ( dwBufLen != 0 ) {
+         ImmGetCompositionString( hIMC, GCS_COMPSTR, lpCompStr, dwBufLen );
+         lpCompStr[ dwBufLen ] = 0;
+     }
+     else {
+         strcpy(lpCompStr,"  ");
+         dwBufLen = 2;
+     }
+     
+     //
+     // Display new composition chars.
+     //
+     DisplayCompString(lpCompStr, dwBufLen);
+    
+
+exit2:
+
+     ImmReleaseContext( hwnd, hIMC );
+
+}
+
+
+//***********************************************************************
+//
+// void GetResultStr()
+//
+// This handles WM_IME_COMPOSITION with GCS_RESULTSTR flag on.
+//
+//***********************************************************************
+
+void GetResultStr( HWND hwnd )
+{
+    DWORD       dwBufLen;               // Storage for length of result str.
+    HIMC        hIMC;                   // Input context handle.
+
+    //
+    // If fail to get input context handle then do nothing.
+    //
+
+    if ( !( hIMC = ImmGetContext( hwnd ) ) )
+        return;
+
+    //
+    // Determines how much memory space to store the result string.
+    // Applications should call ImmGetCompositionString with
+    // GCS_RESULTSTR flag on, buffer length zero, to get the bullfer
+    // length.
+    //
+
+    if ( ( dwBufLen = ImmGetCompositionString( hIMC, GCS_RESULTSTR,
+                                  (void FAR *)NULL, (DWORD) 0 ) ) <= 0 )
+        goto exit2;
+
+    if ( dwBufLen > 99 )
+        goto exit2;
+    //
+    // Reads in the result string.
+    //
+
+    ImmGetCompositionString( hIMC, GCS_RESULTSTR, lpCompStr, dwBufLen );
+
+    //
+    // Displays the result string.
+    //
+
+    DisplayCompString(lpCompStr, dwBufLen);
+
+
+exit2:
+
+    ImmReleaseContext( hwnd, hIMC );
+
+}
+
+void ImeUIStartComposition(HWND hwnd)
+{
+     bInComposition = TRUE;
+     //GetResultStr( hwnd );
+}
+
+void ImeUIComposition(HWND hwnd, WPARAM wParam,LPARAM CompFlag)
+{
+    
+    if ( CompFlag & GCS_RESULTSTR ) {
+        GetResultStr( hwnd );
+    }
+    else if ( CompFlag & GCS_COMPSTR ) {
+        GetCompositionStr( hwnd, CompFlag );
+    }
+
+}
+
+void ImeUIEndComposition(HWND hwnd)
+{
+    bInComposition = FALSE;
+    //GetResultStr( hwnd );
+}
+
+
+char* ImeGetTempComposition(void)
+{
+    if ( bInComposition == TRUE /* && bCommandMode == FALSE */) {
+        HIMC    hImc;
+        DWORD   dwConvMode, dwSentMode;
+        if ( (  hImc = ImmGetContext( s_hwnd ) ) ) {
+            ImmGetConversionStatus(hImc, &dwConvMode, &dwSentMode);
+            if ( (dwConvMode & IME_CMODE_NATIVE) )
+                return lpCompStr;
+        }
+    }
+    return NULL;
+}
+
+void ImeNotify(WPARAM w, LPARAM l)
+{
+    HIMC    hImc;
+    DWORD   dwConvMode, dwSentMode;
+    if ( (  hImc = ImmGetContext( s_hwnd ) ) ) {
+        ImmGetConversionStatus(hImc, &dwConvMode, &dwSentMode);
+        if ( dwConvMode & IME_CMODE_NATIVE)
+            bImeKorean = TRUE;
+        else
+            bImeKorean = FALSE;
+    }
+}
+
+void ImeOpenClose(HWND hWnd, BOOL fFlag)
+{
+    HIMC            hIMC;
+
+    //
+    // If fFlag is true then open IME; otherwise close it.
+    //
+
+    if ( !( hIMC = ImmGetContext( hWnd ) ) )
+        return;
+
+    ImmSetOpenStatus( hIMC, fFlag );
+
+    ImmReleaseContext( hWnd, hIMC );
+}
+
+void ImeInit(void)
+{
+/*    
+    static HKL hkl;
+    HFONT hFont;
+    LOGFONT    lFont;
+
+    if ( ( hFont = (HFONT)SendMessage( s_hwnd, WM_GETFONT, 0, 0L ) ) != NULL ) {
+        if ( GetObject( hFont, sizeof(LOGFONT), (LPVOID)&lFont ) ) {
+            HIMC	hImc;
+            if ( (  hImc = ImmGetContext( s_hwnd ) ) ) {
+		 ImmSetCompositionFont( hImc, &lFont );
+                 ImmReleaseContext( s_hwnd, hImc );
+            }
+        }
+    }
+
+    ImmGetProperty( GetKeyboardLayout(0),IGP_PROPERTY );
+
+
+    hkl = GetKeyboardLayout(0L);
+ */   
+}
+
+
+/************************************************************************
+*
+*   IsDBCSTrailByte - returns TRUE if the given byte is a DBCS trail byte
+*
+*                     The algorithm searchs backward in the string, to some
+*                     known character boundary, counting consecutive bytes
+*                     in the lead byte range. An odd number indicates the
+*                     current byte is part of a two byte character code.
+*
+*   INPUT: PCHAR  - pointer to a preceding known character boundary.
+*          PCHAR  - pointer to the character to test.
+*
+*   OUTPUT:BOOL   - indicating truth of p==trailbyte.
+*
+************************************************************************/
+
+int IsDBCSTrailByte( char *base, char *p )
+{
+    int lbc = 0;    // lead byte count
+
+    if ( base > p )
+        return 0;
+    if ( strlen(base) <= (size_t)(p-base) )
+        return 0;
+
+    while ( p > base ) {
+	if ( !IsDBCSLeadByte(*(--p)) )
+	    break;
+	lbc++;
+    }
+
+    return (lbc & 1);
+}
diff -b -u -r -N ../vim-5.0/src/winime.h src/winime.h
--- ../vim-5.0/src/winime.h	Thu Jan  1 09:00:00 1970
+++ src/winime.h	Fri Feb 20 19:36:33 1998
@@ -0,0 +1,18 @@
+
+#ifdef USE_GUI_WIN32
+extern void ImeSetEnglishMode(void);
+extern void ImeSetOriginMode(void);
+
+extern void ImeUIStartComposition(HWND);
+extern void ImeUIComposition(HWND,WPARAM,LPARAM);
+extern void ImeUIEndComposition(HWND);
+extern void ImeNotify(WPARAM,LPARAM);
+
+char* ImeGetTempComposition(void);
+
+void ImeOpenClose(HWND hWnd, BOOL fFlag);
+void ImeInit(void);
+
+
+int IsDBCSTrailByte( char *base, char *p );
+#endif
\ No newline at end of file
